use utf8;
use strict;
use warnings FATAL => 'all';

package Xyzzy::Static;

use Xyzzy::Handler -self;

field file => undef;
field contentdir => sub { shift->cfg->contentdir };

sub handle {
	my $req = new Xyzzy::Request::Static(ctx => shift, cfg => $self);
	my $doc = new Xyzzy::Document::Static(req => $req);

	return $doc->response;
}

package Xyzzy::Request::Static;

use Xyzzy::Request -self;

sub file {
	return $self->{file} if exists $self->{file};

	my $cfg = $self->cfg;

	my $path = $self->path_components;
	my $file = $cfg->file;
	if($file) {
		die $cfg->error(404) if @$path;
		$file = $self->contentdir . '/' . $file . '.xml'
			unless ord($file) == 47; # /
	} else {
		foreach(@$path) {
			unless(/^[a-z0-9]+([._,-]+[a-z0-9]+)*$/i) {
				my $info = join('/', @$path);
				die $cfg->error(403, "Bad path: '$info'");
			}
		}
		$path = ['index'] unless @$path;
		$file = join('/', $cfg->contentdir, @$path) . '.xml';
	}

	die $cfg->error(404) unless -f $file;
	die $cfg->error(403) unless -r _;

	return $self->{file} = $file;
}

package Xyzzy::Document::Static;

use Xyzzy::Document::Styled -self;

sub build {
	super;

	$self->addChunks(0, $self->req->file);
}
